@@ -1,5 +1,7 @@
 from django.http import JsonResponse, HttpResponse
 from django.shortcuts import render
+from django.utils.decorators import method_decorator
+from django.views.decorators.csrf import csrf_exempt
 from furl import furl
 from django.views.generic import View
 from json import loads as unjsonize
@@ -76,31 +78,31 @@ class BaseView(View):
 class BaseCrudView(BaseView):
 
     def get(self, request, filters, **kwargs):
-        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
         self.data = crud.get()
         return self._respond()
 
     def post(self, request, filters, **kwargs):
         print('in post')
-        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
         body = unjsonize(request.body.decode())
         self.data = crud.post(**body, **kwargs)
         return self._respond()
 
     def bulk_post(self, request, filters, **kwargs):
-        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
         body = unjsonize(request.body.decode())
         self.data = crud.bulk_post(data=body, **filters, **kwargs)
         return self._respond()
 
     def put(self, request, filters, **kwargs):
-        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
         body = unjsonize(request.body.decode())
         self.data = crud.put(**body, **kwargs)
         return self._respond()
 
     def delete(self, request, filters, **kwargs):
-        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
         if not crud.delete():
             return HttpResponse(status=404)
         return self._respond()
