@@ -1,15 +1,12 @@
 from oauth2_provider.views.mixins import ProtectedResourceMixin, OAuthLibMixin
-from .base import view_catch_error, BaseCrudView, BaseView
+from .base import method_decorator, csrf_exempt, view_catch_error, BaseCrudView, BaseView
 from .lookups import ChoicesView
 
-from django.utils.decorators import method_decorator
-from django.views.decorators.csrf import csrf_exempt
-
 
 # def set_user(f): TODO
 #     def wrap(self, request, *args, **kwargs):
 #         self.user = request.resource_owner
-#         return f(self=self, request=request, *args, **kwargs)
+    #         return f(self=self, request=request, *args, **kwargs)
 #
 #     wrap.__doc__ = f.__doc__
 #     wrap.__name__ = f.__name__
